/*
 * folio.cc: Class representing a page number for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <string>

#include "utils.h"
#include "folio.h"

folio::folio(const std::string& pgtag, const std::string& suffix, bool reverse)
  : m_pgnum(to_pgnum(pgtag)), m_pgtag(pgtag),
    m_suffix(suffix), m_reverse(reverse) { }

std::string folio::suffix() const
{
  return m_suffix;
}

unsigned int folio::pgnum() const
{
  return m_pgnum;
}

std::string folio::pgtag() const
{
  return m_pgtag;
}

bool folio::reverse() const
{
  return m_reverse;
}

std::string folio::log_write() const
{
  std::string val(m_pgtag);
  if (val != "") // ignore cross-references
    {
      if (m_suffix == "|(") // **** LaTeX-dependent code
	val += "-";
      else
	val += ", ";
    }
  return val;
}
