/*
 * folio.h: Class representing a page number for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef DP_INDIGO_FOLIO
#define DP_INDIGO_FOLIO

#include <string>

class folio {
 public:
  // Caution: As currently implemented, pgtag must be an arabic number or
  // valid roman numeral no larger than 39 (xxxix).
  explicit folio(const std::string& pgtag,
		 const std::string& suffix = "",
		 bool reverse = false);

  std::string suffix() const;
  unsigned int pgnum() const;
  std::string pgtag() const;
  bool reverse() const;

  std::string log_write() const;

 private:
  unsigned int m_pgnum;
  std::string m_pgtag;
  std::string m_suffix;
  bool m_reverse; // cause page::mark to search backward?
}; // end of folio class

#endif /* DP_INDIGO_FOLIO */
