/*
 * index_data.cc: Class representing an index for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 12 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <list>
//#include <cstdlib>
#include <iostream>

#include "typedefs.h"
#include "index_line.h"
#include "index_entry.h"
#include "file.h"

#include "utils.h"
#include "logger.h"

#include "index_data.h"

using std::string;

index_data::index_data(FILENAME entries, logger& error_mgr)
{
  std::ifstream input(entries.c_str());
  if (!input)
    error("Can't open file \"" + entries + "\"");

  // else
  string linebuf;
  unsigned int line_number(1);

  // load and parse lines of input
  while (getline(input, linebuf))
    m_contents.push_back(index_line(line_number++, linebuf, error_mgr));

  input.close();

  // else build list of entries
  std::list<index_line> tmp(rejoin(m_contents, error_mgr));

  if (tmp.size() == 0)
    error_mgr.err(0, "The file "+entries+" contains no indexable entries.");

  else
    {
      std::list<index_line>::iterator curr = tmp.begin();
      while (curr != tmp.end())
	{
	  (*curr).add_to_list(m_entries);
	  ++curr;
	}
    }
}

// actions: add entries to a file
void index_data::mark(file& infile) const
{
  for (std::list<index_entry>::const_iterator lp = m_entries.begin();
       lp != m_entries.end(); ++lp)
    (*lp).mark(infile);
}

// check whether page numbers are all in range
void index_data::check_ranges(const file& infile, logger& error_mgr)
{
  for (std::list<index_entry>::const_iterator ep = m_entries.begin();
       ep != m_entries.end(); ++ep)
    infile.check_ranges((*ep).pages(), error_mgr);
}


void index_data::write(FILENAME outfile) const
{
  std::ofstream output(outfile.c_str());
  if (!output)
    error("Can't open file \"" + outfile + "\""); // bomb out

  for (std::list<index_line>::const_iterator lp = m_contents.begin();
       lp != m_contents.end(); ++lp)
    (*lp).write(output);

  output.close();
}

