/*
 * index_data.h: Class representing an index for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef DP_INDIGO_INDEX_DATA
#define DP_INDIGO_INDEX_DATA

#include <list>

#include "typedefs.h"
#include "index_line.h"
#include "index_entry.h"

class file;
class logger;

class index_data {
 public:
  index_data(FILENAME entriesname, logger&);

  // add entries to a file
  void mark(file&) const;

  // see if page numbers are all in range
  void check_ranges(const file&, logger&);

  // write formatted output, return true if no warnings/errors
  void write(FILENAME) const;

 private:
  std::list<index_line> m_contents;
  std::list<index_entry> m_entries;
}; // end of index_data class

#endif /* DP_INDIGO_INDEX_DATA */
