/*
 * index_entry.cc: Class representing an index entry for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <list>
#include <string>

#include "typedefs.h"
#include "folio.h"
#include "file.h"

#include "index_entry.h"

// index class provides meaningful initialization by calling add_page
index_entry::index_entry(const std::string& search, const std::string& replace)
  : m_search(search), m_replace(replace) { }

void index_entry::add_page(const folio& pgnum)
{
  m_pages.push_back(pgnum);
}

void index_entry::mark(file& infile) const
{
  for (std::list<folio>::const_iterator pg = m_pages.begin();
       pg != m_pages.end(); ++pg)
    infile.mark((*pg), *this);
}

const std::string& index_entry::search() const
{
  return m_search;
}

const std::string& index_entry::replace() const
{
  return m_replace;
}

const std::list<folio>& index_entry::pages() const
{
  return m_pages;
}
