/*
 * index_entry.h: Class representing an index entry for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef DP_INDIGO_INDEX_ENTRY
#define DP_INDIGO_INDEX_ENTRY

#include <list>
#include <string>

#include "typedefs.h"
#include "folio.h"

class file;

class index_entry {
 public:
  index_entry(const std::string& search, const std::string& replace);

  void add_page(const folio&);

  void mark(file&) const;

  const std::string& search() const;
  const std::string& replace() const;
  const std::list<folio>& pages() const;

 private:
  std::string m_search;
  std::string m_replace;

  std::list<folio> m_pages;
}; // end of index_entry class

#endif /* DP_INDIGO_INDEX_ENTRY */
