/*
 * index_line.h: Class representing an index line for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 11 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef DP_INDIGO_INDEX_LINE
#define DP_INDIGO_INDEX_LINE

#include <fstream>
#include <list>
#include <string>

#include "typedefs.h"
#include "folio.h"

class index_entry;
class index_line;
class logger;

std::list<index_line> rejoin(std::list<index_line>, logger&);

enum indigo_line_type {ITEM, SUBITEM, SUBSUBITEM, FOLIOS, BLANK, ERROR};

class index_line {
 public:
  // constructor classifies lines and parses input
  index_line(unsigned int line_number, const std::string& data, logger&);

  void add_to_list(std::list<index_entry>& entries) const;

  void write(std::ofstream&) const;

 private:
  int m_number;
  indigo_line_type m_type;

  std::string m_search;
  std::string m_replace;
  std::string m_comment;

  std::list<folio> m_pages;

  void merge(index_line); // get arg's folio numbers
  void make_subitem_of(const index_line&); // mark as subitem of arg

  friend std::list<index_line> rejoin(std::list<index_line>, logger&);
}; // end of index_line class

#endif /* DP_INDIGO_INDEX_LINE */
