/*
 * indigo.cc: A program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 12 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#include <string>
#include <sstream>
#include <iostream>

#include "utils.h"
#include "file.h"
#include "logger.h"

#include "typedefs.h"
#include "index_data.h"

int main(int argc, char* argv[]) {

  if (argc != 3)
    error("Usage: " + std::string(argv[0]) + " <entries> <LaTeX file>.tex");

  std::string entriesname(argv[1]);
  std::string filename(argv[2]);

  // bomb out on mismatch
  std::string basename(check_extension(filename, ".tex") + "_indigo");

  std::string outname(basename + ".tex");
  std::string igoname(basename + ".igo");
  std::string logname(basename + ".log");

  logger error_mgr(entriesname, filename);
  // read index entry file, register errors and warnings
  index_data entries(entriesname, error_mgr);

  if (error_mgr.errors())
    {
      error_mgr.write(logname, igoname, outname);
      error("There were errors processing " + entriesname
	    + "; please see " + logname + ".");
    }

  // read LaTeX source file
  file infile(filename, error_mgr);

  if (error_mgr.errors())
    {
      error_mgr.write(logname, igoname, outname);
      error("There were errors processing " + filename
	    + "; please see " + logname + ".");
    }

  // look for out-of-range entries
  entries.check_ranges(infile, error_mgr);

  if (error_mgr.errors())
    {
      error_mgr.write(logname, igoname, outname);
      error("There were out-of-range index entries; please see "+logname+".");
    }

  else
    {
      // index the source file
      entries.mark(infile);

      // make numbered backups
      mv_safe(igoname);
      mv_safe(outname);

      // write pretty-formatted index
      entries.write(igoname);

      // write indexed source file
      infile.write(outname);

      // write the log file
      error_mgr.write(logname, igoname, outname);
      return(0);
    }
}
