/*
 * line.cc: Class representing a file line for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1b
 * Last Change: 23 July, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <list>
#include <string>
#include <fstream>
#include <iostream>

#include "utils.h"

#include "line.h"

line::line(const std::string& data)
  : m_data(data), m_eol(read_newline(data) + "\n") // restore newline
{ }

int line::mark(const std::string& tag)
{
  // **** LaTeX-specific code
  m_tags.push_back(std::string("\\index{" + tag + "}%" + m_eol));
  return 1;
}

// If find criterion in our data, append "\\index{tag}" to m_tags
int line::mark(const std::string& search, const std::string& tag)
{
  if (match(lowercase(m_data), lowercase(search)))
    {
      // **** LaTeX-specific code
      m_tags.push_back(std::string("\\index{" + tag + "}%" + m_eol));
      return 1;
    }
  else
    return 0;
}

void line::write(std::ofstream& output) const
{
  output << m_data << std::endl;
  if (m_tags.size() != 0)
    for (std::list<std::string>::const_iterator lp = m_tags.begin();
	 lp != m_tags.end(); ++lp)
      output << *lp;
}
