/*
 * logger.cc: Warning message class for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 12 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <string>
#include <fstream>
#include <iostream>

#include "utils.h"
#include "log_line.h"

#include "logger.h"

logger::logger(const std::string& indexfile, const std::string& latexfile)
  : m_indexfile(indexfile), m_latexfile(latexfile) { }

logger& logger::warn(const std::string& msg)
{
  m_warnings.push_back(log_line(msg));
  return *this;
}

logger& logger::err(unsigned int num, const std::string& msg)
{
  m_errors.push_back(log_line(num, msg));
  return *this;
}

void logger::write(FILENAME filename, FILENAME idx, FILENAME src)
{
  using std::endl;
  std::ofstream output(filename.c_str());
  if (!output)
    error("Can't open file \"" + filename + "\"");

  // else
  output << "indigo log report" << endl
	 << "  Index entry file:  " << m_indexfile << endl
	 << "  LaTeX source file: " << m_latexfile << endl << endl;

  if (m_errors.size() == 0)
    {
      output << "No errors found!" << endl << endl;

      // No need to print warnings if there were errors
      if (m_warnings.size() == 0)
	output << "No warnings!" << endl;
      else
	{
	  output << "** The issues below may require attention."
		 << "  Please consult the source file " << src << "."
		 << endl << endl;

	  for (std::list<log_line>::const_iterator lp(m_warnings.begin());
	       lp != m_warnings.end(); ++lp)
	    output << (*lp).write() << endl;
	}
    }

  else
    {
      m_errors.sort(); // put line numbers in non-decreasing order
      output << "**** The errors below need to be corrected."
	     << endl << endl;

      for (std::list<log_line>::const_iterator lp(m_errors.begin());
	   lp != m_errors.end(); ++lp)
	output << (*lp).write() << endl;

      output << endl;
    }

  output.close();
}


bool logger::errors() const
{
  return m_errors.size() != 0;
}
