/*
 * logger.h: Warning message manager class for indigo,
 * a program to insert index entries into LaTeX documents
 *
 * Version 1.1
 * Last Change: 12 January, 2010
 *
 *
 * Copyright (C) 2009, 2010
 *
 * Andrew D. Hwang (DP: adhere)
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 *
 *
 * indigo is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * indigo is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with pglatex; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef DP_INDIGO_LOGGER
#define DP_INDIGO_LOGGER

#include <string>
#include <list>

#include "typedefs.h"
#include "log_line.h"

class logger {
 public:
  logger(const std::string& indexfile, const std::string& latexfile);

  logger& warn(const std::string& msg);
  logger& err(unsigned int lineno, const std::string& msg);

  // write log messages to outfile
  // caller passes names of index and latex src files
  void write(FILENAME outfile, FILENAME idx, FILENAME src);

  bool errors() const;

 private:
  std::string m_indexfile;
  std::string m_latexfile;

  std::list<log_line> m_warnings;
  std::list<log_line> m_errors;
}; // end of logger class

#endif /* DP_INDIGO_LOGGER */
